Crate sqlx_json

Crate sqlx_json 

Database-agnostic row-to-JSON conversion and query result traits for sqlx.

Provides RowExt for converting a single database row into a [Value::Object] and QueryResult for extracting affected row counts. Implementations are provided for SqliteRow, PgRow, and MySqlRow.

Traits

QueryResult
Extracts the affected row count from a backend query result.
RowExt
Converts a single database row into a JSON object.